@@ -1,16 +1,15 @@
 #!/usr/bin/env perl
 use strict;
 use warnings;
+use lib 'lib';
+use lib 't/lib';
 use Term::ANSIColor qw(colored);
 use UNIVERSAL::require;
 use UNIVERSAL::source_location_for;
+use Pod::Usage;
 my ($class, $method) = @ARGV;
 unless ($class && $method) {
-    print <<'...';
-USAGE:
-    $ source_location.pl Module method
-...
-    exit;
+    pod2usage;
 }
 
 $class->require or die $@;
@@ -21,8 +20,16 @@ my ($file, $line) = do {
 
 unless (defined($file) && defined($line)) {
     print colored(qq|method "${class}::$method" is not found.|, 'red'), "\n";
-    exit;
+    exit 1;
 }
 
 print colored('FILENAME ', 'green') .  "$file\n";
 print colored('LINE     ', 'green') .  "$line\n";
+
+=encoding utf-8
+
+=head1 SYNOPSIS
+
+  $ source_location.pl <Module> <method>
+
+=cut
